pub fn parse_project(src_dir: &Path) -> Result<SchemaRegistry, Error>Expand description
Parse all Rust source files in a directory and extract schema definitions.
pub fn parse_project(src_dir: &Path) -> Result<SchemaRegistry, Error>Parse all Rust source files in a directory and extract schema definitions.